"""add partial kw

Peek Plugin Database Migration Script

Revision ID: 758f26706069
Revises: 0736e757d1ec
Create Date: 2020-06-01 12:35:51.862282

"""

# revision identifiers, used by Alembic.
revision = "758f26706069"
down_revision = "0736e757d1ec"
branch_labels = None
depends_on = None

import sqlalchemy as sa
from alembic import op


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    op.alter_column(
        "SearchObject",
        "propertiesJson",
        new_column_name="fullKwPropertiesJson",
        schema="core_search",
    )

    op.add_column(
        "SearchObject",
        sa.Column("partialKwPropertiesJson", sa.String(), nullable=True),
        schema="core_search",
    )
    # ### end Alembic commands ###


def downgrade():
    op.alter_column(
        "SearchObject",
        "fullKwPropertiesJson",
        new_column_name="propertiesJson",
        schema="core_search",
    )

    op.drop_column(
        "SearchObject", "partialKwPropertiesJson", schema="core_search"
    )



import logging

from sqlalchemy import BigInteger
from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import orm
from sqlalchemy.sql.schema import ForeignKey
from sqlalchemy.sql.schema import Index
from vortex.Tuple import Tuple
from vortex.Tuple import addTupleType

from peek_core_search._private.PluginNames import searchTuplePrefix
from .DeclarativeBase import DeclarativeBase

logger = logging.getLogger(__name__)


@addTupleType
class SearchObject(DeclarativeBase, Tuple):
    __tablename__ = "SearchObject"
    __tupleType__ = searchTuplePrefix + "SearchObjectTable"

    id = Column(BigInteger, primary_key=True, autoincrement=True)

    #:  The object that this routs is for
    objectTypeId = Column(
        Integer,
        ForeignKey("SearchObjectType.id", ondelete="CASCADE"),
        nullable=False,
    )

    key = Column(String, nullable=False)

    chunkKey = Column(String, nullable=False)

    fullKwPropertiesJson = Column(String, nullable=True)

    partialKwPropertiesJson = Column(String, nullable=True)

    packedJson = Column(String, nullable=True)

    __table_args__ = (
        Index("idx_SearchObject_objectTypeId", objectTypeId),
        Index("idx_SearchObject_key", key, unique=True),
        Index("idx_SearchObject_chunkKey", chunkKey),
    )

    @orm.reconstructor
    def __init__(self, **kwargs):
        Tuple.__init__(self, **kwargs)



from peek_core_search._private.PluginNames import searchTuplePrefix
from vortex.Tuple import Tuple, addTupleType, TupleField


@addTupleType
class SearchResultDetailTuple(Tuple):
    """Search Result Detail Tuple

    This tuple represents the details of a search result.
    """

    __tupleType__ = searchTuplePrefix + "SearchResultDetailTuple"

    #:  The name of the detail
    name: str = TupleField()

    #:  The value of the detail
    value: str = TupleField()



import logging

from twisted.internet.defer import Deferred

from vortex.TupleAction import TupleActionABC
from vortex.handler.TupleActionProcessor import TupleActionProcessorDelegateABC
from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler

logger = logging.getLogger(__name__)


class MainController(TupleActionProcessorDelegateABC):
    def __init__(
        self, dbSessionCreator, tupleObservable: TupleDataObservableHandler
    ):
        self._dbSessionCreator = dbSessionCreator
        self._tupleObservable = tupleObservable

    def shutdown(self):
        pass

    def processTupleAction(self, tupleAction: TupleActionABC) -> Deferred:
        raise NotImplementedError(tupleAction.tupleName())

    def agentNotifiedOfUpdate(self, updateStr):
        logger.debug("Agent said : %s", updateStr)
